Index: src/uk/me/parabola/imgfmt/app/lbl/LBLFile.java
===================================================================
--- src/uk/me/parabola/imgfmt/app/lbl/LBLFile.java	(revision 4834)
+++ src/uk/me/parabola/imgfmt/app/lbl/LBLFile.java	(working copy)
@@ -60,6 +60,8 @@
 	// Shift value for the label offset, we always use 1 here.
 	private static final int OFFSET_MULTIPLIER = 1;
 
+	private static final int MAX_LABEL_LEN = 170; // Garmin software doesn't display longer labels
+
 	public LBLFile(ImgChannel chan, Sort sort) {
 		this.sort = sort;
 		lblHeader.setSort(sort);
@@ -129,8 +131,29 @@
 	 * @return A reference to the created label.
 	 */
 	public Label newLabel(String text) {
+		return newLabel(text, true);
+	}
+	
+	/**
+	 * Add a new label with the given text.  Labels are shared, so that identical
+	 * text is always represented by the same label.
+	 *
+	 * @param text The text of the label, it will be in uppercase.
+	 * @param cutToMaxLen if true, cut labels to max length. 
+	 * @return A reference to the created label.
+	 */
+	public Label newLabel(String text, boolean cutToMaxLen) {
+		if (text != null && cutToMaxLen) {
+			int trimmedLen = text.length();
+			if (trimmedLen > MAX_LABEL_LEN) {
+				trimmedLen = MAX_LABEL_LEN;
+				while (text.charAt(trimmedLen) == ' ')
+					trimmedLen--;
+				text = text.substring(0, trimmedLen + 1);
+			}
+		}
 		EncodedText encodedText = textEncoder.encodeText(text);
-
+		
 		Label l = labelCache.get(encodedText);
 		if (l == null) {
 			l = new Label(encodedText.getChars());
Index: src/uk/me/parabola/imgfmt/app/map/Map.java
===================================================================
--- src/uk/me/parabola/imgfmt/app/map/Map.java	(revision 4834)
+++ src/uk/me/parabola/imgfmt/app/map/Map.java	(working copy)
@@ -176,7 +176,7 @@
 	 * gets shown when the device starts (sometimes?).
 	 */
 	public void addCopyright(String str) {
-		Label cpy = lblFile.newLabel(str);
+		Label cpy = lblFile.newLabel(str, false);
 		treFile.addCopyright(cpy);
 	}
 
Index: src/uk/me/parabola/imgfmt/app/trergn/ExtTypeAttributes.java
===================================================================
--- src/uk/me/parabola/imgfmt/app/trergn/ExtTypeAttributes.java	(revision 4834)
+++ src/uk/me/parabola/imgfmt/app/trergn/ExtTypeAttributes.java	(working copy)
@@ -204,17 +204,17 @@
 		if(note == null) {
 			String ns = attributes.get("note");
 			if(ns != null)
-				note = lbl.newLabel(ns);
+				note = lbl.newLabel(ns, false);
 		}
 		if(intDesig == null) {
 			String ids = attributes.get("int-desig");
 			if(ids != null)
-				intDesig = lbl.newLabel(ids);
+				intDesig = lbl.newLabel(ids, false);
 		}
 		if(localDesig == null) {
 			String lds = attributes.get("local-desig");
 			if(lds != null)
-				localDesig = lbl.newLabel(lds);
+				localDesig = lbl.newLabel(lds, false);
 		}
 	}
 
